@@ -35,11 +35,11 @@ Data::Random::Flexible - Flexible fast-to-write profilable randoms
 
 =head1 VERSION
 
-Version 1.05
+Version 1.06
 
 =cut
 
-our $VERSION = '1.05';
+our $VERSION = '1.06';
 
 
 =head1 SYNOPSIS
@@ -192,7 +192,7 @@ sub engine {
         return;
     }
 
-    return $engines;
+    return keys %$engines;
 }
 
 =head1 store()
